@@ -1,14 +1,16 @@
 """ Configures logging with stackdriver
 """
 
-import logging  # pragma: no coverage
+import logging
+import time
 
-import google.cloud.logging  # pragma: no coverage
+import google.cloud.logging
 
 
-def setup_logging(level=logging.INFO):  # pragma: no coverage
+def setup_logging(level=logging.INFO, sleep=5):  # pragma: no coverage
     """ Setup logging
     """
+    time.sleep(sleep)
     client = google.cloud.logging.Client()
     excluded_logger_defaults = (
         "google.cloud",
